/* 
Steve Ansolabehere, Eitan Hersh, Ken Shepsle
Replication File for "Movers, Stayers and Registration"
May 1, 2012


This file first shows how we create the aggregate statistics in Table 1 and the aggregate 
statistics used to create Figure 4. The individual-level data come from the 2008 American
Community Survey (available from the Census Bureau) and from Catalist's 1% Analytics sample
available from Catalist for purchace.

Following our coding to create the tables of aggregates, this files then shows how to generate
Figures 1-4 based on the aggregate statistics.

The tables of aggregates are available in the attached Excel file, "QJPS_replication_aggregate_tables". 
Table 1 appears in one tab; the statistics required for Figure 4 appear in a second tab.

*/





*To generate Table 1

/*Step 1: American Community Survey
The 2008 ACES 1-Year PUMS file can be downloaded at
http://www2.census.gov/acs2008_1yr/pums/csv_pus.zip

The data come in two separate .csv files. Respondents living in half of the U.S. states 
are in each file, presumably divided on account of the size of the dataset. We combined the files 
before analyzing. A codebook is included in the zipped file from the Census website.
*/

keep cit agep pwgtp mig
*Retains necessary variables for analysis

gen age = agep
gen agecohort = "18-19" if age <=19 & age >=18 & age !=.
replace agecohort = "20-21" if age <=21 & age >=20 & age !=.
replace agecohort = "22-23" if age <=23 & age >=22 & age !=.
replace agecohort = "24-25" if age <=25 & age >=24 & age !=.
replace agecohort = "26-27" if age <=27 & age >=26 & age !=.
replace agecohort = "28-29" if age <=29 & age >=28 & age !=.
replace agecohort = "30-31" if age <=31 & age >=30 & age !=.
replace agecohort = "32-33" if age <=33 & age >=32 & age !=.
replace agecohort = "34-35" if age <=35 & age >=34 & age !=.
replace agecohort = "36-37" if age <=37 & age >=36 & age !=.
replace agecohort = "38-39" if age <=39 & age >=38 & age !=.
replace agecohort = "40-41" if age <=41 & age >=40 & age !=.
replace agecohort = "42-43" if age <=43 & age >=42 & age !=.
replace agecohort = "44-45" if age <=45 & age >=44 & age !=.
replace agecohort = "46-47" if age <=47 & age >=46 & age !=.
replace agecohort = "48-49" if age <=49 & age >=48 & age !=.
replace agecohort = "50-51" if age <=51 & age >=50 & age !=.
replace agecohort = "52-53" if age <=53 & age >=52 & age !=.
replace agecohort = "54-55" if age <=55 & age >=54 & age !=.
replace agecohort = "56-57" if age <=57 & age >=56 & age !=.
replace agecohort = "58-59" if age <=59 & age >=58 & age !=.
replace agecohort = "60-61" if age <=61 & age >=60 & age !=.
replace agecohort = "62-63" if age <=63 & age >=62 & age !=.
replace agecohort = "64-65" if age <=65 & age >=64 & age !=.
replace agecohort = "66-67" if age <=67 & age >=66 & age !=.
replace agecohort = "68-69" if age <=69 & age >=68 & age !=.
replace agecohort = "70-71" if age <=71 & age >=70 & age !=.
replace agecohort = "72-73" if age <=73 & age >=72 & age !=.
replace agecohort = "74-75" if age <=75 & age >=74 & age !=.
replace agecohort = "76-77" if age <=77 & age >=76 & age !=.
replace agecohort = "78-79" if age <=79 & age >=78 & age !=.
replace agecohort = "80+" if age  >=80 & age !=.
*Generates 2-year age cohorts

gen citizen = cit
recode citizen 1 2 3 4= 1 5 = 0
*An indicator variable for citizenship

gen lived_oneyearplus = mig
recode lived 2 3 =0 
*An indicator for non-movers

tab agecohort if citizen == 1 [aw=pwgtp]
*Generates "Citizen Sample", Column 1 of Table 1

*To scale the ACS sample to the full population of U.S. Citizens, we multiply 
*the values in Column 1 by a factor 96, so that the full population equals
*206,072,000, the citizen population reported by File and Crissey (2010) as described in the manuscript.
*This scaling generates the values in Column 2, Table 2

tab agecohort lived if citizen == 1 [aw=pwgtp], row nofreq
*Generates the non-mover rate, Column 3 of Table 1

/* Step 2: Catalist Data
Registration data come from Catalist's 1% analytics sample, available for purchase from Catalist.
The sample used here was assembled in the spring of 2010. Note that Catalist normally
samples based on all records in its database, including the records of non-registrants. The sample
in our analysis was drawn from a random sample only of registered voters.
*/


use  sy_deadwood ca_voter  ca_age using catalist_sample.dta

gen age = ca_age - 1
*So as to have our sample reflect the ages of voters at the time of 2008 election, we substract 1 year
*from voters' birthdates.

gen agecohort2 = "18-19" if age <=19 & age >=18 & age !=.
replace agecohort2 = "20-21" if age <=21 & age >=20 & age !=.
replace agecohort2 = "22-23" if age <=23 & age >=22 & age !=.
replace agecohort2 = "24-25" if age <=25 & age >=24 & age !=.
replace agecohort2 = "26-27" if age <=27 & age >=26 & age !=.
replace agecohort2 = "28-29" if age <=29 & age >=28 & age !=.
replace agecohort2 = "30-31" if age <=31 & age >=30 & age !=.
replace agecohort2 = "32-33" if age <=33 & age >=32 & age !=.
replace agecohort2 = "34-35" if age <=35 & age >=34 & age !=.
replace agecohort2 = "36-37" if age <=37 & age >=36 & age !=.
replace agecohort2 = "38-39" if age <=39 & age >=38 & age !=.
replace agecohort2 = "40-41" if age <=41 & age >=40 & age !=.
replace agecohort2 = "42-43" if age <=43 & age >=42 & age !=.
replace agecohort2 = "44-45" if age <=45 & age >=44 & age !=.
replace agecohort2 = "46-47" if age <=47 & age >=46 & age !=.
replace agecohort2 = "48-49" if age <=49 & age >=48 & age !=.
replace agecohort2 = "50-51" if age <=51 & age >=50 & age !=.
replace agecohort2 = "52-53" if age <=53 & age >=52 & age !=.
replace agecohort2 = "54-55" if age <=55 & age >=54 & age !=.
replace agecohort2 = "56-57" if age <=57 & age >=56 & age !=.
replace agecohort2 = "58-59" if age <=59 & age >=58 & age !=.
replace agecohort2 = "60-61" if age <=61 & age >=60 & age !=.
replace agecohort2 = "62-63" if age <=63 & age >=62 & age !=.
replace agecohort2 = "64-65" if age <=65 & age >=64 & age !=.
replace agecohort2 = "66-67" if age <=67 & age >=66 & age !=.
replace agecohort2 = "68-69" if age <=69 & age >=68 & age !=.
replace agecohort2 = "70-71" if age <=71 & age >=70 & age !=.
replace agecohort2 = "72-73" if age <=73 & age >=72 & age !=.
replace agecohort2 = "74-75" if age <=75 & age >=74 & age !=.
replace agecohort2 = "76-77" if age <=77 & age >=76 & age !=.
replace agecohort2 = "78-79" if age <=79 & age >=78 & age !=.
replace agecohort2 = "80+" if age  >=80 & age !=.


gen deadwood =1 if sy_deadwood == "DEAD" | sy_deadwood == "PROBDEAD"
recode deadwood .=0
*Removes records that Catalist estimates to be deadwood

tab agecohort if deadwood == 0 
*Generates Column 4, Table 1
*Note that as this is a 1\% sample of registration records, 
*Column 5 is equal to 100 times the values in Column 4.

*Columns 6 and 7 of Table 1 are functions of Columns 1-5, as defined in Table 1 of the manuscript.




*****To generate aggregate data for Figure 4******


*Figure 4 - Actual Registration Rates of Young Age Groups
*This figure uses single-year age cohorts for young voters
*The citizen population estimate is generated through the ACS
gen agecohort2 = "18" if age == 18 & age !=.
replace agecohort2 = "19" if age == 19 & age !=.
replace agecohort2 = "20" if age == 20 & age !=.
replace agecohort2 = "21" if age == 21 & age !=.
replace agecohort2 = "22" if age == 22 & age !=.
replace agecohort2 = "23" if age == 23 & age !=.
replace agecohort2 = "24" if age == 24 & age !=.
replace agecohort2 = "25" if age == 25 & age !=.
replace agecohort2 = "26" if age == 26 & age !=.
replace agecohort2 = "27" if age == 27 & age !=.
replace agecohort2 = "28" if age == 28 & age !=.
replace agecohort2 = "29" if age == 29 & age !=.
replace agecohort2 = "30" if age == 30 & age !=.
replace agecohort2 = "31" if age == 31 & age !=.
replace agecohort2 = "32" if age == 32 & age !=.
replace agecohort2 = "33" if age == 33 & age !=.
replace agecohort2 = "34" if age == 34 & age !=.

tab agecohort if citizen == 1 [aw=pwgtp]
*Mirroring the strategy in Table 1, the ACS data is scaled
*to approximate the national citizen population estimates.
*For the single-year categories, each value is multiplied by 113.17


*From Catalist
gen agecohort2 = "18" if age == 18 & age !=.
replace agecohort2 = "19" if age == 19 & age !=.
replace agecohort2 = "20" if age == 20 & age !=.
replace agecohort2 = "21" if age == 21 & age !=.
replace agecohort2 = "22" if age == 22 & age !=.
replace agecohort2 = "23" if age == 23 & age !=.
replace agecohort2 = "24" if age == 24 & age !=.
replace agecohort2 = "25" if age == 25 & age !=.
replace agecohort2 = "26" if age == 26 & age !=.
replace agecohort2 = "27" if age == 27 & age !=.
replace agecohort2 = "28" if age == 28 & age !=.
replace agecohort2 = "29" if age == 29 & age !=.
replace agecohort2 = "30" if age == 30 & age !=.
replace agecohort2 = "31" if age == 31 & age !=.
replace agecohort2 = "32" if age == 32 & age !=.
replace agecohort2 = "33" if age == 33 & age !=.
replace agecohort2 = "34" if age == 34 & age !=.

tab agecohort3  if deadwood == 0 

**************************************************************************
**************************************************************************
********************************FIGURES***********************************
**************************************************************************
**************************************************************************

*Summary data described above is imported into STATA.


gen t= _n

label define agegroup 1 "18-19" 2 "20-21" 3 "22-23" 4 "24-25" 5 "26-27" ///
6 "28-29" 7 "30-31" 8 "32-33" 9 "34-35" 10 "36-37" 11 "38-39" 12 "40-41" ///
13 "42-43" 14 "44-45" 15 "46-47" 16 "48-49" 17 "50-51" 18 "52-53" 19 "54-55" ///
20 "56-57" 21 "58-59" 22 "60-61" 23 "62-63" 24 "64-65" 25 "66-67"  26 "68-69" ///
27 "70-71" 28 "72-73" 29 "74-75" 30 "76-77" 31 "78-79" 32 "80+" 

label values t agegroup

ren var8 reg_rate
*Registration Rate

gen s = var4^2

*********************FIGURE 1

gen r = (reg_rate-((reg_rate[_n-1])*s))/(1-((reg_rate[_n-1])*s))
replace r = reg_rate if _n ==1

*To find average r for all age groups
ren var3 citpop
egen tot_pop = total(citpop)
gen rweight = r*citpop
egen tot_rweight = total(rweight)
gen ave_r = tot_rweight/tot_pop

twoway (bar r t, fcolor(gs10) lcolor(none) barwidth(.8)) ///
(line ave_r t, lcolor(black) lwidth(thick) lpattern(dash)), ///
ytitle(r) ylabel(0(.1)1) xtitle(Two-Year Age Cohorts) xlabel(1(2)32, ///
labels angle(forty_five) valuelabel) legend(off) plotregion(style(none)) ///
text(.65 22 "Average r for all ages (weighted by pop.)")




****************FIGURE 2: Comparison of models


nl exp2a: reg_rate t
predict p2
*Non-linear least squares estimate

reg reg_rate t
predict p_ols
*Standard OLS estimate

gen t_sq = t^2

reg reg_rate t t_sq
predict p_ols_sq
*OLS with squared term

gen cohort1 = t
recode cohort1 1 2 3 4 5 6 7 8  =1 nonmis=0
gen cohort2 = t
recode cohort2  9 10 11 12 13 14 15 16 = 1 nonmis = 0
gen cohort3 = t
recode cohort3 17 18 19 20 21 22 23 24 = 1 nonmis =0
gen cohort4 = t
recode cohort4 25 26 27 28 29 30 31 32 =1 nonmis =0

reg reg_rate cohort2 cohort3 cohort4
predict p_dummies
*OLS with 4 indiscator variables


label var p_ols "OLS"
label var p_ols_sq "OLS with squared term"
label var p_dummies "OLS with 4 indicators"
label var p2 "Stayer-Mover (constant s)"
label var reg_rate "Registration Rate"


twoway (line p2 t, lcolor(black)  lwidth(medthick)) ///
(line p_ols t,  lpattern(dot) lwidth(medthick)  lcolor(gray)) ///
(line p_ols_sq t, lpattern(longdash) lwidth(medthick)    lcolor(gray)) /// 
(line p_dummies t, lpattern(shortdash) lwidth(medthick)   lcolor(gray)) ///
 (scatter reg_rate t, mcolor(black) msize(medlarge) msymbol(circle_hollow)), ///
ytitle(Registration Rate) ytitle(, size(medlarge)) ylabel(.5(.1)1) ///
xtitle(Two-Year Age Cohorts) xtitle(, size(medlarge)) ///
xlabel(1(2)32, labels angle(forty_five) valuelabel) ///
xmtick(##2) legend(region(lcolor(none))) plotregion(style(none))  ///
title(Actual and Expected Registration Rates by Age Cohort, size(large)) scheme(s1color) ///
subtitle(Comparison of Models)



*****************FIGURE 3: Varying mobility rates model


gen xols = s*(reg_rate[_n-1])
replace xols = 0 if xols ==.

reg reg_rate xols
predict p2b2

label var p2b2 "Stayer-Mover (variable s)"


twoway (line p2b2 t, lcolor(black) lwidth(thick) lpattern(dash)) ///
 (scatter reg_rate t, mcolor(black) msize(medlarge) msymbol(circle_hollow)), ///
ytitle(Registration Rate)ytitle(, size(medlarge)) ylabel(.5(.1)1) ///
xtitle(Two-Year Age Cohorts) xtitle(, size(medlarge)) ///
xmtick(##2) xlabel(1(2)32, labels angle(forty_five) valuelabel) ///
legend(region(lcolor(none))) plotregion(style(none))  ///
title(Actual and Expected Registration Rates by Age Cohort, size(large)) scheme(s1color) ///
subtitle(Varying Mobility Rates with Age)


****************FIGURE 4: Single year age groups for young registrants

clear
*import summary data into STATA

ren var5 reg_rate
label var reg_rate "Registration Rate"
ren var1 age

twoway  (scatter reg_rate age, mcolor(black) msize(medlarge) msymbol(circle_hollow)), ///
ytitle(Registration Rate) ytitle(, size(medlarge)) ylabel(.5(.1)1) ///
xtitle(Single-Year Age Cohorts) xtitle(, size(medlarge)) ///
xlabel(18(1)34, labels angle(forty_five) valuelabel) ///
legend(region(lcolor(none))) plotregion(style(none))  ///
title(Actual Registration Rates for Young Age Groups, size(large)) scheme(s1color) 


